@@ -1,3 +1,4 @@
+/* $Id$ */
 #include "gd.h"
 #include <stdio.h>
 #include "gdtest.h"
@@ -5,18 +6,23 @@
 int main()
 {
 	gdImagePtr im, tile;
-	int im_black, tile_black;
+	int im_black, tile_white, tile_black;
 	int x,y, error = 0;
-	char path[1024];
 
 /*	fputs("flag 0\n", stdout); */
 	im = gdImageCreate(150, 150);
-	tile = gdImageCreate(36, 36);
-	gdImageColorAllocate(tile,255,255,255); /* allocate white for background color */
-	tile_black = gdImageColorAllocate(tile,0,0,0);
+
+
+	tile = gdImageCreateTrueColor(36, 36);
+
+	tile_white = gdImageColorAllocate(tile,255,255,255);
+	tile_black = gdImageColorAllocate(tile,55,0,0);
 	gdImageColorAllocate(im,255,255,255); /* allocate white for background color */
 	im_black = gdImageColorAllocate(im,0,0,0);
 
+	gdImageFill(tile, 0,0, tile_white);
+	gdImageColorTransparent(tile, tile_black);
+	gdImageColorTransparent(im, im_black);
 
 	/* create the dots pattern */
 	for (x=0; x<36; x+=2) {
@@ -35,16 +41,15 @@ int main()
 	gdImageFill(im, 0, 0, 0xffffff);
 /*	fputs("flag 2\n", stdout); */
 	gdImageFill(im, 0, 0, 0xffffff);
-/*	fputs("flag 2\n", stdout); */
+/*	fputs("flag 3\n", stdout); */
 
-
-	sprintf(path, "%s/gdimagefill/bug00002_2_exp.png", GDTEST_TOP_DIR);
-	if (!gdAssertImageEqualsToFile(path, im)) {
+	if (!gdAssertImageEqualsToFile("gdimagefill/bug00002_3_exp.png", im)) {
 		error = 1;
 	}
 
 	/* Destroy it */
 	gdImageDestroy(im);
+	gdImageDestroy(tile);
 	return error;
 }
 
