@@ -7,24 +7,15 @@
 int main()
 {
 	gdImagePtr im, exp;
-	char path[2048];
-	const char *file_im = "gdimagerotate/php_bug_64898.png";
-	const char *file_exp = "gdimagerotate/php_bug_64898_exp.png";
 	FILE *fp;
+	int error = 0;
 
-	sprintf(path, "%s/%s", GDTEST_TOP_DIR, file_im);
-
-	fp = fopen(path, "rb");
-
-	if (!fp) {
-		gdTestErrorMsg("opening PNG %s for reading failed.\n", path);
-		return 1;
-	}
-
+	fp = gdTestFileOpen("gdimagerotate/php_bug_64898.png");
+(void)fp;
 	im = gdImageCreateTrueColor(141, 200);
 
 	if (!im) {
-		gdTestErrorMsg("loading %s failed.\n", path);
+		gdTestErrorMsg("loading failed.\n");
 		return 1;
 	}
 
@@ -41,17 +32,13 @@ int main()
 		return 1;
 	}
 
-	sprintf(path, "%s/%s", GDTEST_TOP_DIR, file_exp);
-
-	if (!gdAssertImageEqualsToFile(path, exp)) {
-		printf("comparing rotated image to %s failed.\n", path);
-		gdImageDestroy(im);
-		gdImageDestroy(exp);
-		return 1;
+	if (!gdAssertImageEqualsToFile("gdimagerotate/php_bug_64898_exp.png", exp)) {
+		printf("comparing rotated image failed.\n");
+		error = 1;
 	}
 
 	gdImageDestroy(exp);
 	gdImageDestroy(im);
 
-	return 0;
+	return error;
 }
